@@ -15,8 +15,9 @@
 #' @param outcome The column name of the actual outcomes.
 #' @param group Sensitive group to examine.
 #' @param probs The column name or vector of the predicted probabilities (numeric between 0 - 1). If not defined, argument preds needs to be defined.
-#' @param preds The column name or vector of the predicted outcome (categorical outcome). If not defined, argument probs needs to be defined.
-#' @param outcome_levels The desired levels of the predicted outcome (categorical outcome). If not defined, all unique values of outcome are used.
+#' @param preds The column name or vector of the predicted binary outcome (0 or 1). If not defined, argument probs needs to be defined.
+#' @param preds_levels The desired levels of the predicted binary outcome. If not defined, levels of the outcome variable are used.
+#' @param outcome_base Base level for the target variable used to compute fairness metrics. Default is the first level of the outcome variable.
 #' @param cutoff Cutoff to generate predicted outcomes from predicted probabilities. Default set to 0.5.
 #' @param base Base level for sensitive group comparison
 #'
@@ -30,26 +31,21 @@
 #' @examples
 #' data(compas)
 #' spec_parity(data = compas, outcome = 'Two_yr_Recidivism', group = 'ethnicity',
-#' probs = 'probability', preds = NULL, outcome_levels = c('no', 'yes'),
+#' probs = 'probability', preds = NULL, preds_levels = c('no', 'yes'),
 #' cutoff = 0.4, base = 'Caucasian')
 #' spec_parity(data = compas, outcome = 'Two_yr_Recidivism', group = 'ethnicity',
-#' probs = NULL, preds = 'predicted', outcome_levels = c('no', 'yes'),
+#' probs = NULL, preds = 'predicted', preds_levels = c('no', 'yes'),
 #' cutoff = 0.5, base = 'Hispanic')
 #'
 #' @export
 
 spec_parity <- function(data, outcome, group,
-                        probs = NULL, preds = NULL, outcome_levels = NULL, cutoff = 0.5, base = NULL) {
+                        probs = NULL, preds = NULL, preds_levels = NULL, outcome_base = NULL, 
+                        cutoff = 0.5, base = NULL) {
 
     # convert types, sync levels
-    group_status <- as.factor(data[, group])
-    outcome_status <- as.factor(data[, outcome])
-    if (is.null(outcome_levels)) {
-        outcome_levels <- unique(outcome_status)
-    }
-    levels(outcome_status) <- outcome_levels
     if (is.null(probs) & is.null(preds)) {
-        stop({"Either probs or preds have to be supplied"})
+        stop({'Either probs or preds have to be supplied'})
     }
     if (is.null(probs)) {
         if (length(preds) == 1) {
@@ -62,12 +58,21 @@ spec_parity <- function(data, outcome, group,
         }
         preds_status <- as.factor(as.numeric(probs > cutoff))
     }
-    levels(preds_status) <- outcome_levels
+    
+    group_status   <- as.factor(data[, group])
+    outcome_status <- as.factor(data[, outcome])
+    
+    if (is.null(preds_levels)) {
+        preds_levels <- levels(outcome_status)
+    }
+    levels(preds_status) <- preds_levels
+    outcome_status <- relevel(outcome_status, preds_levels[1])
+    preds_status   <- relevel(preds_status,   preds_levels[1])
 
     # check lengths
     if ((length(outcome_status) != length(preds_status)) | (length(outcome_status) !=
         length(group_status))) {
-        stop("Outcomes, predictions/probabilities and group status must be of the same length")
+        stop('Outcomes, predictions/probabilities and group status must be of the same length')
     }
 
     # relevel group
@@ -79,21 +84,28 @@ spec_parity <- function(data, outcome, group,
     # placeholder
     val <- rep(NA, length(levels(group_status)))
     names(val) <- levels(group_status)
+    
+    # set outcome base
+    if (is.null(outcome_base)) {
+        outcome_base <- levels(preds_status)[1]
+    }
 
     # compute value for all groups
     for (i in levels(group_status)) {
-        cm <- caret::confusionMatrix(preds_status[group_status == i], outcome_status[group_status ==
-            i], mode = "everything")
-        metric_i <- cm$byClass[2]
+        cm <- caret::confusionMatrix(preds_status[group_status == i], 
+                                     outcome_status[group_status == i], 
+                                     mode = 'everything',
+                                     positive = outcome_base)
+        metric_i <- cm$byClass['Specificity']
         val[i] <- metric_i
     }
 
     res_table <- rbind(val, val/val[[1]])
-    rownames(res_table) <- c("Specificity", "Specificity Parity")
+    rownames(res_table) <- c('Specificity', 'Specificity Parity')
 
     # conversion of metrics to df
     val_df <- as.data.frame(res_table[2, ])
-    colnames(val_df) <- c("val")
+    colnames(val_df) <- c('val')
     val_df$groupst <- rownames(val_df)
     val_df$groupst <- as.factor(val_df$groupst)
 
@@ -104,15 +116,15 @@ spec_parity <- function(data, outcome, group,
     val_df$groupst <- relevel(val_df$groupst, base)
 
     p <- ggplot(val_df, aes(x = groupst, weight = val, fill = groupst)) + geom_bar(alpha = 0.5) +
-        coord_flip() + theme(legend.position = "none") + labs(x = "", y = "Specificity Parity")
+        coord_flip() + theme(legend.position = 'none') + labs(x = '', y = 'Specificity Parity')
 
     # plotting
     if (!is.null(probs)) {
         probs_vals <- data[, probs]
         q <- ggplot(data, aes(x = probs, fill = group_status)) + geom_density(alpha = 0.5) +
-            labs(x = "Predicted probabilities") + guides(fill = guide_legend(title = "")) +
+            labs(x = 'Predicted probabilities') + guides(fill = guide_legend(title = '')) +
             theme(plot.title = element_text(hjust = 0.5)) + xlim(0, 1) + geom_vline(xintercept = cutoff,
-            linetype = "dashed")
+            linetype = 'dashed')
     }
 
     if (is.null(probs)) {
